package String::Comments::Extract::JavaScript;

use strict;
use warnings;

use base qw/String::Comments::Extract::SlashStar/;

1;
